@@ -61,7 +61,7 @@
 #endif
 
 MainWindow::MainWindow(QWidget *parent)
-    : KMainWindow(parent, Qt::CustomizeWindowHint | Qt::FramelessWindowHint)
+    : KMainWindow(parent, Qt::CustomizeWindowHint | Qt::FramelessWindowHint | Qt::Tool)
 {
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/yakuake/window"), this, QDBusConnection::ExportScriptableSlots);
 
@@ -381,13 +381,13 @@ void MainWindow::setupActions()
     action = actionCollection()->addAction(QStringLiteral("previous-terminal"));
     action->setText(xi18nc("@action", "Previous Terminal"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("go-previous")));
-    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Up));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_Tab));
     connect(action, SIGNAL(triggered()), m_sessionStack, SIGNAL(previousTerminal()));
 
     action = actionCollection()->addAction(QStringLiteral("next-terminal"));
     action->setText(xi18nc("@action", "Next Terminal"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("go-next")));
-    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Down));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::Key_Tab));
     connect(action, SIGNAL(triggered()), m_sessionStack, SIGNAL(nextTerminal()));
 
     action = actionCollection()->addAction(QStringLiteral("close-active-terminal"));
@@ -928,7 +928,7 @@ void MainWindow::applyWindowProperties()
         KWindowSystem::setState(winId(), NET::KeepAbove | NET::Sticky | NET::SkipTaskbar | NET::SkipPager);
 
     KWindowSystem::setOnAllDesktops(winId(), Settings::showOnAllDesktops());
-    KWindowEffects::enableBlurBehind(winId(), Settings::blur());
+    KWindowEffects::enableBlurBehind(windowHandle(), Settings::blur());
 }
 
 void MainWindow::applyWindowGeometry()
@@ -1147,25 +1147,6 @@ void MainWindow::changeEvent(QEvent *event)
     KMainWindow::changeEvent(event);
 }
 
-bool MainWindow::event(QEvent *event)
-{
-    if (event->type() == QEvent::Expose) {
-        // FIXME TODO: We can remove this once we depend on Qt 5.6.1+.
-        // See: https://bugreports.qt.io/browse/QTBUG-26978
-        applyWindowProperties();
-#if (QT_VERSION > QT_VERSION_CHECK(5, 5, 0))
-    } else if (event->type() == QEvent::PlatformSurface) {
-        const QPlatformSurfaceEvent *pSEvent = static_cast<QPlatformSurfaceEvent *>(event);
-
-        if (pSEvent->surfaceEventType() == QPlatformSurfaceEvent::SurfaceCreated) {
-            applyWindowProperties();
-        }
-#endif
-    }
-
-    return KMainWindow::event(event);
-}
-
 bool MainWindow::focusNextPrevChild(bool)
 {
     return false;
@@ -1251,7 +1232,7 @@ void MainWindow::_toggleWindowState()
         } else {
             sharedPreOpenWindow();
             if (KWindowEffects::isEffectAvailable(KWindowEffects::Slide)) {
-                KWindowEffects::slideWindow(winId(), KWindowEffects::TopEdge);
+                KWindowEffects::slideWindow(windowHandle(), KWindowEffects::TopEdge);
             }
 
             show();
